function [O] = group_symm(a,b)
% group_symm(a,b) - constructs the full symmetry group generated by 
%   rotation matrices a and b. Returns group elements as rotation matrices
%   in the structure O.
% 
% 
% Copyright (c) 2013, Lawrence Livermore National Security, LLC.  Produced
% at the Lawrence Livermore National Laboratory.  Written by Jeremy Mason,
% reachable at mason47@llnl.gov.
% 
% CODE-609912. All rights reserved.
% 
% This file is part of the Quaternionic Harmonic Analysis of Texture.  
% Please read LICENSE.txt for Our Notice and GNU General Public License
% information.
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License (as published by
% the Free Software Foundation) version 2, dated June 1991.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
% conditions of the GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with this program; if not, write to the Free Software Foundation, Inc.,
% 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

O = {a;b};

r = 0;
while r < size(O,1)
    oa = O{r+1}*a;
    ob = O{r+1}*b;
    add_oa = true;
    add_ob = true;
    for s = 1:size(O,1)
        if add_oa && max(max(abs(oa\O{s}-eye(3))))<1e-5
            add_oa = false;
        end
        if add_ob && max(max(abs(ob\O{s}-eye(3))))<1e-5
            add_ob = false;
        end
    end
    if add_oa
        O{end+1} = oa;
    end
    if add_ob
        O{end+1} = ob;
    end
    r = r+1;
end

for q = 1:length(O)
    O{q}(abs(O{q})<1e-10) = 0;
end
